package org.test.as7.messaging;

import javax.annotation.Resource;
import javax.ejb.LocalBean;
import javax.ejb.Stateless;
import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.Destination;
import javax.jms.JMSException;
import javax.jms.MessageProducer;
import javax.jms.Session;
import javax.jms.TextMessage;

import org.jboss.logging.Logger;
import org.jboss.logging.Logger.Level;

@Stateless
@LocalBean
public class MessageProducerBean {

    private static Logger logger = Logger.getLogger(MessageProducerBean.class);

    @Resource(mappedName = "java:/JmsXA")
    private ConnectionFactory connectionFactory;
    @Resource(mappedName = "java:/queue/myMessageQueue")
    private Destination myMessageQueue;

    public void sendMessage(final String myMessage) {

        Connection connection = null;
        Session session = null;
        MessageProducer producer = null;
        try {
            connection = connectionFactory.createConnection();
            session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
            producer = session.createProducer(myMessageQueue);

            final TextMessage message = session.createTextMessage();
            message.setStringProperty("message", myMessage);
            
            producer.send(message);

        } catch (final JMSException jmse) {
            logger.logv(Level.ERROR, jmse.getMessage());

        } finally {
            if (connection != null) {
                try {
                    connection.close();
                } catch (final JMSException jmsex) {
                    logger.logv(
                            Level.ERROR,
                            "Failed to cleanup JMS resources: {0}",
                            jmsex.getMessage());
                }
            }
        }
    }
}
